@@ -4,7 +4,7 @@ import os
 import re
 
 from django import forms
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from filebrowser.settings import FOLDER_REGEX
 from filebrowser.utils import convert_filename
