@@ -1,17 +1,15 @@
 # coding: utf-8
 
-# DJANGO IMPORTS
-from django.utils.html import escape
-from django.utils.safestring import mark_safe
 from django.template import Library
 
+
 register = Library()
 DOT = '.'
 
 
 @register.inclusion_tag('filebrowser/include/paginator.html', takes_context=True)
 def pagination(context):
-    page_num = context['page'].number-1
+    page_num = context['page'].number - 1
     paginator = context['p']
 
     if not paginator.num_pages or paginator.num_pages == 1:
